# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/bioacoustics',
                'doc_host': 'https://itepifanio.github.io',
                'git_url': 'https://github.com/itepifanio/bioacoustics',
                'lib_path': 'bioacoustics_augmentation'},
  'syms': { 'bioacoustics_augmentation.augmentations.classical.audio': { 'bioacoustics_augmentation.augmentations.classical.audio.pitch_shift': ( 'classical_audio_augmentations.html#pitch_shift',
                                                                                                                                                  'bioacoustics_augmentation/augmentations/classical/audio.py'),
                                                                         'bioacoustics_augmentation.augmentations.classical.audio.time_shift': ( 'classical_audio_augmentations.html#time_shift',
                                                                                                                                                 'bioacoustics_augmentation/augmentations/classical/audio.py')},
            'bioacoustics_augmentation.augmentations.classical.spectrogram': { 'bioacoustics_augmentation.augmentations.classical.spectrogram._apply_time_warp': ( 'classical_spectrogram_augmentions.html#_apply_time_warp',
                                                                                                                                                                   'bioacoustics_augmentation/augmentations/classical/spectrogram.py'),
                                                                               'bioacoustics_augmentation.augmentations.classical.spectrogram._frequency_masking': ( 'classical_spectrogram_augmentions.html#_frequency_masking',
                                                                                                                                                                     'bioacoustics_augmentation/augmentations/classical/spectrogram.py'),
                                                                               'bioacoustics_augmentation.augmentations.classical.spectrogram._sparse_image_warp': ( 'classical_spectrogram_augmentions.html#_sparse_image_warp',
                                                                                                                                                                     'bioacoustics_augmentation/augmentations/classical/spectrogram.py'),
                                                                               'bioacoustics_augmentation.augmentations.classical.spectrogram._time_masking': ( 'classical_spectrogram_augmentions.html#_time_masking',
                                                                                                                                                                'bioacoustics_augmentation/augmentations/classical/spectrogram.py'),
                                                                               'bioacoustics_augmentation.augmentations.classical.spectrogram.apply_spec_augment': ( 'classical_spectrogram_augmentions.html#apply_spec_augment',
                                                                                                                                                                     'bioacoustics_augmentation/augmentations/classical/spectrogram.py'),
                                                                               'bioacoustics_augmentation.augmentations.classical.spectrogram.pitch_shift': ( 'classical_spectrogram_augmentions.html#pitch_shift',
                                                                                                                                                              'bioacoustics_augmentation/augmentations/classical/spectrogram.py'),
                                                                               'bioacoustics_augmentation.augmentations.classical.spectrogram.random_shifts': ( 'classical_spectrogram_augmentions.html#random_shifts',
                                                                                                                                                                'bioacoustics_augmentation/augmentations/classical/spectrogram.py'),
                                                                               'bioacoustics_augmentation.augmentations.classical.spectrogram.time_shift': ( 'classical_spectrogram_augmentions.html#time_shift',
                                                                                                                                                             'bioacoustics_augmentation/augmentations/classical/spectrogram.py')},
            'bioacoustics_augmentation.augmentations.mix': { 'bioacoustics_augmentation.augmentations.mix._paste_patch': ( 'combination_augmentations.html#_paste_patch',
                                                                                                                           'bioacoustics_augmentation/augmentations/mix.py'),
                                                             'bioacoustics_augmentation.augmentations.mix._rand_bbox': ( 'combination_augmentations.html#_rand_bbox',
                                                                                                                         'bioacoustics_augmentation/augmentations/mix.py'),
                                                             'bioacoustics_augmentation.augmentations.mix.cutmix': ( 'combination_augmentations.html#cutmix',
                                                                                                                     'bioacoustics_augmentation/augmentations/mix.py'),
                                                             'bioacoustics_augmentation.augmentations.mix.mixup': ( 'combination_augmentations.html#mixup',
                                                                                                                    'bioacoustics_augmentation/augmentations/mix.py')},
            'bioacoustics_augmentation.core': { 'bioacoustics_augmentation.core.foo': ( 'core.html#foo',
                                                                                        'bioacoustics_augmentation/core.py')},
            'bioacoustics_augmentation.utils.audio': { 'bioacoustics_augmentation.utils.audio.AudioMetadata': ( 'audio.html#audiometadata',
                                                                                                                'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Spectrogram': ( 'audio.html#spectrogram',
                                                                                                              'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Spectrogram.__init__': ( 'audio.html#spectrogram.__init__',
                                                                                                                       'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Spectrogram.copy': ( 'audio.html#spectrogram.copy',
                                                                                                                   'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Spectrogram.freq_bins': ( 'audio.html#spectrogram.freq_bins',
                                                                                                                        'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Spectrogram.time_frames': ( 'audio.html#spectrogram.time_frames',
                                                                                                                          'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Wav': ( 'audio.html#wav',
                                                                                                      'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Wav.__init__': ( 'audio.html#wav.__init__',
                                                                                                               'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Wav.copy': ( 'audio.html#wav.copy',
                                                                                                           'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Wav.from_spectrogram': ( 'audio.html#wav.from_spectrogram',
                                                                                                                       'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Wav.load': ( 'audio.html#wav.load',
                                                                                                           'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.Wav.to_spectrogram': ( 'audio.html#wav.to_spectrogram',
                                                                                                                     'bioacoustics_augmentation/utils/audio.py'),
                                                       'bioacoustics_augmentation.utils.audio.play_audio': ( 'audio.html#play_audio',
                                                                                                             'bioacoustics_augmentation/utils/audio.py')},
            'bioacoustics_augmentation.utils.generator.guitar_chords': { 'bioacoustics_augmentation.utils.generator.guitar_chords.GuitarSoundGenerator': ( 'guitar_chords.html#guitarsoundgenerator',
                                                                                                                                                           'bioacoustics_augmentation/utils/generator/guitar_chords.py'),
                                                                         'bioacoustics_augmentation.utils.generator.guitar_chords.GuitarSoundGenerator.__init__': ( 'guitar_chords.html#guitarsoundgenerator.__init__',
                                                                                                                                                                    'bioacoustics_augmentation/utils/generator/guitar_chords.py'),
                                                                         'bioacoustics_augmentation.utils.generator.guitar_chords.GuitarSoundGenerator.generate_chord': ( 'guitar_chords.html#guitarsoundgenerator.generate_chord',
                                                                                                                                                                          'bioacoustics_augmentation/utils/generator/guitar_chords.py'),
                                                                         'bioacoustics_augmentation.utils.generator.guitar_chords.GuitarSoundGenerator.generate_note': ( 'guitar_chords.html#guitarsoundgenerator.generate_note',
                                                                                                                                                                         'bioacoustics_augmentation/utils/generator/guitar_chords.py'),
                                                                         'bioacoustics_augmentation.utils.generator.guitar_chords.GuitarSoundGenerator.get_frequency': ( 'guitar_chords.html#guitarsoundgenerator.get_frequency',
                                                                                                                                                                         'bioacoustics_augmentation/utils/generator/guitar_chords.py'),
                                                                         'bioacoustics_augmentation.utils.generator.guitar_chords.GuitarSoundGenerator.to_wav': ( 'guitar_chords.html#guitarsoundgenerator.to_wav',
                                                                                                                                                                  'bioacoustics_augmentation/utils/generator/guitar_chords.py')},
            'bioacoustics_augmentation.utils.image': { 'bioacoustics_augmentation.utils.image.BoundingBox': ( 'image.html#boundingbox',
                                                                                                              'bioacoustics_augmentation/utils/image.py'),
                                                       'bioacoustics_augmentation.utils.image.BoundingBox.area': ( 'image.html#boundingbox.area',
                                                                                                                   'bioacoustics_augmentation/utils/image.py')},
            'bioacoustics_augmentation.utils.plot': { 'bioacoustics_augmentation.utils.plot.plot_spectrogram': ( 'plot.html#plot_spectrogram',
                                                                                                                 'bioacoustics_augmentation/utils/plot.py'),
                                                      'bioacoustics_augmentation.utils.plot.plot_waveform': ( 'plot.html#plot_waveform',
                                                                                                              'bioacoustics_augmentation/utils/plot.py')}}}
